@@ -60,7 +60,8 @@ print.SemiParBIV <- function(x, ...){
   
   cat("\nEQUATION 3")
   
-  if(!(x$margins[2] %in% c("TW"))) cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n")  
+  #if(!(x$margins[2] %in% c("TW"))) 
+  cat("\nLink function for sigma:","log","\n") #else cat("\nLink function for sigma:","qlogis","\n")  
 
   
   #cat("\nLink function for sigma:","log","\n") 
@@ -68,7 +69,9 @@ print.SemiParBIV <- function(x, ...){
   
   
   cat("\nEQUATION 4")
-  if(x$margins[2] %in% c("DAGUM","SM","TW")) cat("\nLink function for nu:","log","\n")  
+  if(x$margins[2] %in% c("DAGUM","SM")) cat("\nLink function for nu:","log","\n")  
+  if(x$margins[2] %in% c("TW")) cat("\nLink function for nu:","qlogis","\n")  
+  
   cat("Formula: "); print(x$formula[[4]]) 
     
 
